# Pezzo Client

<p align="center">
  <strong>
    Pezzo is the open-source LLMOps platform built for developers and teams. In just two lines of code, you can seamlessly troubleshoot your AI operations, collaborate and manage your prompts in one place, and instantly deploy changes to any environment.
  </strong><br/><br/>
  <a href="https://pezzo.cc/discord" target="_blank">
    <img src="https://cdn.pezzo.ai/discord-button.png" height="32" />
  </a>&nbsp;
  <a href="https://pezzo.cc/3qzMpGb" target="_blank">
    <img src="https://cdn.pezzo.ai/read-the-docs-button.png"" height="32" />
  </a>&nbsp;
  <a href="https://pezzo.cc/3qy415j" target="_blank">
    <img src="https://cdn.pezzo.ai/pezzo-cloud-button.png"" height="32" />
  </a>&nbsp;
</p>

<p align="center">
  <a href="https://pezzo.cc/demo-video-gh" target="_blank">
  <img src="https://cdn.pezzo.ai/banner.png" width="900px">
  </a>
</p>

## Installation

To use the Pezzo client with OpenAI:

```sh
pip install pezzo openai
```

## Usage

The Pezzo Documentation contains useful information on how to use the Pezzo client. It covers various use cases such as prompt management, observability, variables, properties, and more.

[Check out the Pezzo Documentation](https://pezzo.cc/3YILPCw)

## Learn more

- 💡 [What is Pezzo?](https://docs.pezzo.ai/introduction/what-is-pezzo)
- 🕹️ [Tutorial: Prompt Management](https://docs.pezzo.ai/introduction/tutorial-prompt-management/overview)
- 📈 [Tutorial: Observability](https://docs.pezzo.ai/introduction/tutorial-observability/overview)
- 📚 [Pezzo SDK Documentation](https://docs.pezzo.ai/client/pezzo-client)

## License

The `pezzo` library is provided under the Apache 2.0 licesnse.
